
#ifndef AKONADI_EXPORT_H
#define AKONADI_EXPORT_H

#ifdef AKONADI_STATIC_DEFINE
#  define AKONADI_EXPORT
#  define AKONADI_NO_EXPORT
#else
#  ifndef AKONADI_EXPORT
#    ifdef akonadi_kde
        /* We are building this library */
#      define AKONADI_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define AKONADI_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef AKONADI_NO_EXPORT
#    define AKONADI_NO_EXPORT 
#  endif
#endif

#ifndef AKONADI_DEPRECATED
#  define AKONADI_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_DEPRECATED_EXPORT
#  define AKONADI_DEPRECATED_EXPORT AKONADI_EXPORT AKONADI_DEPRECATED
#endif

#ifndef AKONADI_DEPRECATED_NO_EXPORT
#  define AKONADI_DEPRECATED_NO_EXPORT AKONADI_NO_EXPORT AKONADI_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef AKONADI_NO_DEPRECATED
#    define AKONADI_NO_DEPRECATED
#  endif
#endif

#endif
